@@ -2,6 +2,7 @@ import json
 import logging
 import os
 import time
+from json import JSONDecodeError
 
 import requests
 from addict import Dict
@@ -77,15 +78,33 @@ class KodexaSession:
             r = requests.get(
                 f"{KodexaPlatform.get_url()}/api/sessions/{self.cloud_session.id}/executions/{execution.id}",
                 headers={"x-access-token": KodexaPlatform.get_access_token()})
-            execution = Dict(json.loads(r.text))
+            try:
+                execution = Dict(json.loads(r.text))
+            except JSONDecodeError:
+                logger.error("Unable to handle response [" + r.text + "]")
+                raise
+
             if status != execution.status:
                 logger.info(f"Status changed from {status} -> {execution.status}")
                 status = execution.status
             time.sleep(1)
 
         if status == "FAILED":
-            logger.error("Failed to execution in session")
-            logger.exception(execution)
+            logger.error("Execution has failed")
+            for step in execution.steps:
+                if step.status == 'FAILED':
+                    logger.error(f"Step {step.name} has failed. {step.exceptionDetails.message}.")
+
+                    if step.exceptionDetails.errorType == 'Validation':
+                        logger.error("Additional validation information has been provided:")
+                        for validation_error in step.exceptionDetails.validationErrors:
+                            logger.error(f"- {validation_error.option} : {validation_error.message}")
+
+                    if step.exceptionDetails.help:
+                        logger.error(f"Additional help is available:\n\n{step.exceptionDetails.help}")
+
+            logger.debug(execution)
+
             raise Exception("Processing has failed")
 
         return execution
@@ -107,9 +126,9 @@ class KodexaSession:
         raw_store = Dict(json.loads(response.text))
         return TableDataStore(raw_store.data.columns, raw_store.data.rows)
 
-    def merge_stores(self, execution, context):
+    def merge_stores(self, execution, context: PipelineContext):
         for store in execution.stores:
-            context.add_store(store.name, self.get_store(execution, store))
+            context.merge_store(store.name, self.get_store(execution, store))
 
 
 class KodexaPipeline:
